@@ -55,9 +55,9 @@
 #define TITRAQ_PREFLOCALLOG     "loglocal"
 #define TITRAQ_DEFLOCALLOG      "no"
 #define TITRAQ_PREFCORBHOST     "corbahost"
-#define TITRAQ_DEFCORBHOST      "localhost"
+#define TITRAQ_DEFCORBHOST      "localhost:8914"
 #define TITRAQ_PREFSOAPHOST     "soaphost"
-#define TITRAQ_DEFSOAPHOST      "localhost"
+#define TITRAQ_DEFSOAPHOST      "localhost/cgi-bin/asdbserv"
 #define TITRAQ_PREFCORBON       "corbaenable"
 #define TITRAQ_DEFCORBON        0
 #define TITRAQ_PREFSOAPON       "soapenable"
@@ -133,6 +133,8 @@
 #define TITRAQ_DEFEDITBAR       true
 #define TITRAQ_PREFVIEWBAR      "viewtoolbar"
 #define TITRAQ_DEFVIEWBAR       true
+#define TITRAQ_PREFPREFBAR      "preftoolbar"
+#define TITRAQ_DEFPREFBAR       true
 #define TITRAQ_PREFWHATBAR      "whattoolbar"
 #define TITRAQ_DEFWHATBAR       true
 
@@ -214,7 +216,8 @@
 #define TITRAQ_IDXFILEBAR       1
 #define TITRAQ_IDXEDITBAR       2
 #define TITRAQ_IDXVIEWBAR       3
-#define TITRAQ_IDXWHATBAR       4
+#define TITRAQ_IDXPREFBAR       4
+#define TITRAQ_IDXWHATBAR       5
 
 // Indexes of character tokens in strings
 #define TITRAQ_IDXSTATERROR     0
