@@ -40,8 +40,8 @@
 // Constructs a Prefpanel as a child of 'pParent', with the 
 // name 'kszName' and widget flags set to 'Flags'.
 //
-// The dialog will by default be modeless, unless you set 'bModal' to
-// true to construct a modal dialog.
+// The dialog will by default be modal, unless you set 'bModal' to
+// false to construct a modeless dialog.
 //
 Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags Flags)
     : QDialog(pParent, kszName, bModal, Flags)
@@ -49,8 +49,8 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     if (!kszName)
         this->setName("Prefpanel");
 
-    setSizeGripEnabled(false);
-    setSizePolicy(QSizePolicy((QSizePolicy::SizeType)5,
+    this->setSizeGripEnabled(false);
+    this->setSizePolicy(QSizePolicy((QSizePolicy::SizeType)5,
         (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth()));
 
     m_pVlayout = new QVBoxLayout(this, 11, 6, "Formlayout");
@@ -220,13 +220,13 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 //
 // Sets the strings of the subwidgets using the current language
 //
-void Prefpanel::textChange()
+void Prefpanel::textChange(void)
 {
     this->setCaption(tr("AS Applicate Preferences", "Personal preferences are persistent across sessions"));
 
     m_pTabselect->changeTab(m_pBoolpage, tr("General"));
     m_pTabselect->changeTab(m_pGeneralpage, tr("Paths"));
-    m_pTabselect->changeTab(m_pRemotepage, tr("Remote"));
+    m_pTabselect->changeTab(m_pRemotepage, tr("Hosts"));
 
     m_pOkaybutton->setText(tr("Okay", "Comment for Okaybutton"));
     QToolTip::add(m_pOkaybutton, tr("Applies and saves changes", "Comment for tooltip Okaybutton"));
@@ -250,7 +250,7 @@ void Prefpanel::textChange()
     QToolTip::add(m_pUserline, tr("The user name", "Comment for toolTip Userline"));
     QToolTip::add(m_pHomeline, tr("The home directory", "Comment for toolTip Homeline"));
 
-    m_pRembox->setTitle(tr("Remote host names", "Comment for Genbox"));
+    m_pRembox->setTitle(tr("Remote host names", "Comment for Rembox"));
     m_pCorbalabel->setText(tr("CORBA host", "Comment for Corbalabel"));
     m_pSoaplabel->setText(tr("SOAP host", "Comment for Soaplabel"));
     QToolTip::add(m_pCorbaline, tr("The CORBA host name", "Comment for toolTip Corbaline"));
