@@ -58,9 +58,11 @@
 #include "as_generic.h"         // Generic classes
 #include "as_uuid.h"            // UUID classes
 #include "as_datedit.h"         // Derived from QDateEdit
+#include "as_amount.h"          // Derived from QTimeEdit
 #include "as_crc.h"             // Useful Qualistring class
 #include "as_pref.h"            // For Preferences class
 #include "as_panel.h"           // For Prefpanel class
+#include "as_reportpanel.h"     // For Reportpanel class
 #include "as_sfile.h"           // For Simplefile class
 #include "as_table.h"           // For TiTable class
 
@@ -1556,8 +1558,12 @@ void Titraqform::showRemarkcol(void)
 //
 void Titraqform::genReport(void)
 {
-    Prototype Unimp;
-    Unimp.doMbox();
+    Reportpanel *pReport = NULL;    // The local report panel
+
+    // Create a new local report window
+    pReport = new Reportpanel(m_pMaintable, m_pPrefs, this, "Locreportpanel");
+    pReport->exec();    // Modal panel handler
+    delete pReport;     // Dispose Panel object
 }
 
 //
